django-payments
===============

Universal payment handling for Django

Documentation: https://django-payments.readthedocs.org/


Additional payment providers
----------------------------

* [BNL POSitivity (BNP Paribas)](https://github.com/esistgut/django-payments-bnlepos)
